@@ -11,21 +11,21 @@ xmlNodeSetPtr
 domXPathSelect( xmlNodePtr refNode, xmlChar * xpathstring );
 
 xmlXPathObjectPtr
-domXPathFind( xmlNodePtr refNode, xmlChar * xpathstring );
+domXPathFind( xmlNodePtr refNode, xmlChar * xpathstring, int to_bool );
 
 xmlNodeSetPtr
 domXPathCompSelect( xmlNodePtr refNode, xmlXPathCompExprPtr comp );
 
 xmlXPathObjectPtr
-domXPathCompFind( xmlNodePtr refNode, xmlXPathCompExprPtr comp );
+domXPathCompFind( xmlNodePtr refNode, xmlXPathCompExprPtr comp, int to_bool );
 
 xmlNodeSetPtr
 domXPathSelectCtxt( xmlXPathContextPtr ctxt, xmlChar * xpathstring );
 
 xmlXPathObjectPtr
-domXPathFindCtxt( xmlXPathContextPtr ctxt, xmlChar * xpathstring );
+domXPathFindCtxt( xmlXPathContextPtr ctxt, xmlChar * xpathstring, int to_bool );
 
 xmlXPathObjectPtr
-domXPathCompFindCtxt( xmlXPathContextPtr ctxt, xmlXPathCompExprPtr comp );
+domXPathCompFindCtxt( xmlXPathContextPtr ctxt, xmlXPathCompExprPtr comp, int to_bool );
 
 #endif
